@@ -424,3 +424,44 @@ class TestStoreAuthz(TestCase):
                                 headers=self.bob_headers)
         assert response.status_code == 200, "response should be 200 OK"
 
+    def test_search_public(self):
+        # Not logged in: no results
+        results = self._get_search_results()
+        assert results['total'] == 0
+        assert results['rows'] == []
+
+    def test_search_authenticated(self):
+        # Logged in as Bob: 1 result
+        results = self._get_search_results(headers=self.bob_headers)
+        assert results['total'] == 1
+        assert results['rows'][0]['id'] == self.anno_id
+
+        # Logged in as Charlie: 0 results
+        results = self._get_search_results(headers=self.charlie_headers)
+        assert results['total'] == 0
+        assert results['rows'] == []
+
+    def test_search_raw_public(self):
+        # Not logged in: no results
+        results = self._get_search_raw_results()
+        assert results['hits']['total'] == 0
+        assert results['hits']['hits'] == []
+
+    def test_search_raw_authorized(self):
+        # Logged in as Bob: 1 result
+        results = self._get_search_raw_results(headers=self.bob_headers)
+        assert results['hits']['total'] == 1
+        assert results['hits']['hits'][0]['_source']['id'] == self.anno_id
+
+        # Logged in as Charlie: 0 results
+        results = self._get_search_raw_results(headers=self.charlie_headers)
+        assert results['hits']['total'] == 0
+        assert results['hits']['hits'] == []
+
+    def _get_search_results(self, qs='', **kwargs):
+        res = self.cli.get('/api/search?{qs}'.format(qs=qs), **kwargs)
+        return json.loads(res.data)
+
+    def _get_search_raw_results(self, qs='', **kwargs):
+        res = self.cli.get('/api/search_raw?{qs}'.format(qs=qs), **kwargs)
+        return json.loads(res.data)
